@@ -724,7 +724,7 @@ class BaseExperiment:
         jsonlog_path = f"{jsonlog_folder}/validation_metrics.json"
         # saving results
         if isinstance(model, BaseEstimator):
-            tensorboard_logdir = self.logger.get_logdir()
+            tensorboard_logdir = self.logger.log_dir
         else:
             tensorboard_logdir = self.logger.experiment.get_logdir()
 
