@@ -24,8 +24,7 @@ def set_default_parameters(config)->None:
         config.update({'l1_strength' : DEFAULT_L1_STRENGTH})
     if 'momentum' not in config.keys():
         config.update({'momentum' : 0.9})
-    if 'scheduler' not in config.keys():
-        config.update({'scheduler' : None})
+
 def initialize_model(
     model_type : "pl.LightningModule", 
     dims : int, 
